@@ -8,10 +8,10 @@ import f61d.LOGO as LOGO
 #from f61d.__version__ import *
 from math import ceil
 from tqdm import *
-from setu import setu,getDesktop
+from f61d.setu import setu,getDesktop
 
 
-VERSION = (0,5,3)
+VERSION = (0,5,4)
 VERSION = '.'.join(map(str, VERSION))
 
 
